This is a package with a script that creates a web-based viewer for single cell
data. The main script is cbBuild. It accepts an expression matrix and cell
annotation (meta data) file. It creates an index.html, various .json and binary
data files, copies javascript files into the same directory. The resulting
webpage allows to move between datasets and to color the plot by gene or
annotation.
